import requests

from data.typehints import CreateFlightSchema
from data.errors import RequestReturnedException

BASE_URL = "https://roavflights.com/openapi"


class LandonApiWrapper:
    def __init__(self, api_key: str):
        self.body = {"apikey": api_key}

    def get_flights(self):
        req = requests.get(BASE_URL + "/flights/get", json=self.body)
        json_data = req.json()

        if req.ok and json_data:
            return json_data['flights']
        else:
            raise RequestReturnedException(json_data)

    def create_flight(self, options: CreateFlightSchema):
        body = dict(self.body, **options)

        req = requests.post(BASE_URL + "/flights/create", json=body)
        json_data = req.json()

        if req.ok and json_data:
            return json_data
        else:
            raise RequestReturnedException(json_data)

    def delete_flight(self, flightID: str):
        body = dict(self.body, **{"flightID": flightID})

        req = requests.post(BASE_URL + "/flights/delete", json=body)
        json_data = req.json()

        if req.ok and json_data:
            return json_data
        else:
            return RequestReturnedException(json_data)



import aiohttp

from ..data.typehints import CreateFlightSchema
from ..data.errors import RequestReturnedException

BASE_URL = "https://roavflights.com/openapi"


class AsyncLandonApiWrapper:
    def __init__(self, api_key: str, session: aiohttp.ClientSession = None):
        self.body = {"apikey": api_key}

        self.session = session

    async def make_request(self, method: str, url, options: dict):
        if not self.session:
            match method:
                case "GET":
                    async with aiohttp.ClientSession() as session:
                        async with session.get(url, json=options) as req:
                            return req
                case "POST":
                    async with aiohttp.ClientSession() as session:
                        async with session.post(url, json=options) as req:
                            return req
        else:
            match method:
                case "GET":
                    req = await self.session.get(url, json=options)
                    return req
                case "POST":
                    req = await self.session.post(url, json=options)
                    return req

    async def get_flights(self):
        req = await self.make_request("GET", BASE_URL + "/flights/get", self.body)
        json_data = await req.json()

        if req.ok and json_data:
            return json_data['flights']
        else:
            raise RequestReturnedException(json_data)

    async def create_flight(self, options: CreateFlightSchema):
        body = dict(self.body, **options)

        req = await self.make_request("POST", BASE_URL + "/flights/create", body)
        json_data = await req.json()

        if req.ok and json_data:
            return json_data
        else:
            raise RequestReturnedException(json_data)

    async def delete_flight(self, flightID: str):
        body = dict(self.body, **{"flightID": flightID})

        req = await self.make_request("POST", BASE_URL + "/flights/delete", body)
        json_data = await req.json()

        if req.ok and json_data:
            return json_data
        else:
            return RequestReturnedException(json_data)



from setuptools import setup

setup(
    name='landon',
    version='1.0.0',
    packages=['src', 'src.landon', 'src.landon.async'],
    url='https://developers.roavflights.com/python_package',
    license='MIT',
    author='felix',
    author_email='holag617@gmail.com',
    description='A package to use Landon\'s openAPI',
    python_requires='>=3.10',
    install_requires=["aiohttp", "requests"]
)
